<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_VE">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Command</source>
        <translation type="unfinished">Comando</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="52"/>
        <source>DBus call</source>
        <translation type="unfinished">llamada DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="53"/>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="143"/>
        <source>Id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="146"/>
        <source>Shortcut</source>
        <translation type="unfinished">Atajo</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="149"/>
        <source>Description</source>
        <translation type="unfinished">Descripcion</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="152"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="155"/>
        <source>Info</source>
        <translation>Información</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="24"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="69"/>
        <source>Add ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="79"/>
        <source>Remove</source>
        <translation type="unfinished">Remover</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="89"/>
        <source>Modify ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="106"/>
        <source>Swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="132"/>
        <source>Multiple actions behaviour:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="140"/>
        <source>First</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="145"/>
        <source>Last</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="150"/>
        <source>None</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation type="unfinished">Nada</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="155"/>
        <source>All</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="180"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="200"/>
        <source>Close</source>
        <translation type="unfinished">Cerrar</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="191"/>
        <source>Restore Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="192"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
